.. include:: ../../README.rst


.. toctree::
   :caption: About
   :hidden:
   :includehidden:
   :maxdepth: 2

   Readme <self>
   quickstart
   changelog
   contributing


.. toctree::
   :caption: Python API reference
   :hidden:
   :includehidden:
   :glob:
   :maxdepth: 2

   api/*


.. toctree::
   :caption: Command line interface
   :hidden:
   :includehidden:
   :maxdepth: 2

   cli/cli
